[dia/dia-0-97] dia-win-remote.exe was unable to locate Dia with the integrated UI.



commit c5c1833d678325a3fc980418545eff3ff5928bc2
Author: Steffen Macke <sdteffen sdteffen de>
Date:   Wed Aug 12 21:37:06 2009 +0200

    dia-win-remote.exe was unable to locate Dia with the integrated UI.

 app/dia-win-remote.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/app/dia-win-remote.c b/app/dia-win-remote.c
index 32c5037..eb7ec97 100644
--- a/app/dia-win-remote.c
+++ b/app/dia-win-remote.c
@@ -3,9 +3,9 @@
  *
  * dia-win-remote.c
  * Copyright (C) 2002, 2004, 2006 Edward G. Bruck <ebruck users sourceforge net>
- * Copyright (C) 2006, 2009 , 2010 Steffen Macke <sdteffen sdteffen de>
+ * Copyright (C) 2006, 2009, 2010 Steffen Macke <sdteffen sdteffen de>
  *
- * dia-win-remote is a program that allows the user running 9x/2000/XP 
+ * dia-win-remote is a program that allows the user running 2000/XP/Vista 
  * to open a dia file in an already running Dia process. If Dia 
  * isn't running, dia-win-remote will launch it and open the requested 
  * file(s).
@@ -305,7 +305,7 @@ int DragAndDropDia(HWND hWnd, int nArgs, LPWSTR *szArglist, int start_at)
  */ 
 BOOL CALLBACK FindDiaWindow(HWND hWnd, LPARAM lParam)
 {
-    char szTitle[40]; /* should be enough to find Dia */
+    char szTitle[MAX_PATH + 40]; /* should be enough to find diaw.exe */
 
     if (GetWindowText(hWnd, szTitle, sizeof(szTitle)) != 0)
     {
@@ -313,7 +313,7 @@ BOOL CALLBACK FindDiaWindow(HWND hWnd, LPARAM lParam)
         char* pszToken = strtok(szTitle, " ");
         while(pszToken != NULL)
         {
-            if (stricmp(pszToken,"Dia") == 0)
+            if (stricmp(pszToken,"diaw.exe") == 0)
             {
                 /* sanity check class name */         
                 char szClass[20]; /* should be enough */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]